Documentation
¶
Index ¶
- Constants
- type Conn
- func (c *Conn) Close() error
- func (c *Conn) Expunge() error
- func (c *Conn) Fetch(uid string) (string, error)
- func (c *Conn) LoginSASL(username, password string) error
- func (c *Conn) Search(qstr string) ([]string, error)
- func (c *Conn) Select(mbox string) error
- func (c *Conn) Store(uid, flags string) error
Constants ¶
const ( IMAPFlagDeleted = "\\Deleted" IMAPFlagSeen = "\\Seen" )
Common IMAP message flags.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Conn ¶
type Conn struct {
// contains filtered or unexported fields
}
Conn knows just enough about the IMAP protocol to run a simple prober (not enough for a real, functional client).
func Dial ¶
func Dial(ctx context.Context, addr string, conf *tls.Config, startTLS bool, log *log.Logger, dnsMap map[string]string) (*Conn, error)
Dial a remote IMAP server (with mandatory TLS). The IMAP connection is bound to the lifetime of the Context.
func (*Conn) Fetch ¶
Fetch a message, returns the whole rfc-822 body.
func (*Conn) LoginSASL ¶
LoginSASL performs a login with SASL AUTH PLAIN mechanism.
func (*Conn) Search ¶
Search the current mailbox for a given query string.
Source Files
¶
- imap.go
Click to show internal directories.
Click to hide internal directories.