package
Version:
v0.0.0-...-9f3b5b4
Opens a new window with list of versions in this module.
Published: Jul 11, 2026
License: LGPL-3.0
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type SSLOptions struct {
CAFile string `json:"ca"`
CertFile string `json:"cert"`
KeyFile string `json:"key"`
SkipValidation bool `json:"skip_validation"`
ServerName string `json:"server_name"`
StartTLS bool `json:"starttls"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.